@@ -14,9 +14,8 @@ use FindBin               qw( $RealBin $RealScript );
 use Pod::Usage            qw( pod2usage );
 
 use Term::Choose           qw( choose );
-use Term::Choose::Util     qw( print_hash choose_a_dir choose_a_number choose_multi insert_sep );
+use Term::Choose::Util     qw( print_hash choose_a_dir choose_a_number settings_menu insert_sep );
 use Term::ReadLine::Simple qw();
-use Text::LineFold         qw();
 
 use if $^O eq 'MSWin32', 'Win32::Console::ANSI';
 
@@ -421,7 +420,7 @@ sub set_options {
                 my $sub_menu = _sub_menus( $choice );
                 my $current = { map { $_->[0] => $opt->{$_->[0]} } @$sub_menu };
                 my $prompt = 'Enable fast list-menu for';
-                _opt_choose_multi( $opt, $sub_menu, $current, $prompt );
+                _opt_settings_menu( $opt, $sub_menu, $current, $prompt );
             }
             elsif ( $choice eq "small_list_size" ) {
                 my $prompt = 'Videos in list-menu';
@@ -467,9 +466,9 @@ sub set_options {
 }
 
 
-sub _opt_choose_multi {
+sub _opt_settings_menu {
     my ( $opt, $sub_menu, $current, $prompt ) = @_;
-    my $changed = choose_multi( $sub_menu, $current, { prompt => $prompt, in_place => 0 } );
+    my $changed = settings_menu( $sub_menu, $current, { prompt => $prompt, in_place => 0 } );
     return if ! $changed;
     for my $key ( keys %$changed ) {
         $opt->{$key} = $changed->{$key};
